@@ -23,7 +23,9 @@ def get_image_data(path_img_file: str) -> torch.Tensor:
     :return: (*torch.Tensor*) A tensor object of the image file.
     """
 
-    return torch.tensor(numpy.array(Image.open(path_img_file).convert('RGB')), dtype=torch.float)
+    img = torch.tensor(numpy.array(Image.open(path_img_file).convert('RGB')), dtype=torch.float)
+
+    return torch.swapaxes(img, 0, 2)
 
 
 def load_dataset(path_metadata_file: str,
@@ -62,7 +64,7 @@ def load_dataset(path_metadata_file: str,
         img = get_image_data(path_imgs + '/' + metadata[i, idx_img_id] + ext_img)
 
         # Swap axes the loaded image to fit the data format into the torchvision library.
-        img = torch.swapaxes(img, 0, 2)
+        # img = torch.swapaxes(img, 0, 2)
 
         if idx_target is None:
             list_data.append(Data(x=img, idx=i, dtype=DTYPE_IMG))
