@@ -197,24 +197,21 @@ class SKLearnModel(Model):
         return self
 
     def predict(self,
-                dataset: Union[Dataset, MultimodalDataset]) -> torch.Tensor:
+                x: Union[torch.tensor, Dataset]) -> torch.Tensor:
         """
         Predict target values for the input data in ``dataset`` using the prediction model.
         If ``selected_dtypes`` is not ``None``, the prediction process is performed only for the selected data types.
 
-        :param dataset: (*Union[Dataset, MultimodalDataset]*) A dataset of the input data.
+        :param x: (*Union[torch.tensor, Dataset]*) A single input or dataset object containing multiple inputs.
         :return: (*torch.Tensor*) Predicted values for the input dataset.
         """
 
-        if isinstance(dataset, Dataset):
-            preds = self.__model.predict(dataset.x.numpy()).reshape(-1, 1)
-        elif isinstance(dataset, MultimodalDataset):
-            x = torch.hstack([d.x for d in dataset.datasets])
-            preds = self.__model.predict(x.numpy()).reshape(-1, 1)
+        if isinstance(x, torch.Tensor):
+            _x = x.numpy().reshape(1, -1)
         else:
-            raise TypeError('A dataset of unsupported data type {} was given.'.format(dataset.__class__))
+            _x = x.x
 
-        return torch.tensor(preds, dtype=torch.float)
+        return torch.tensor(self.__model.predict(_x).reshape(-1, 1))
 
     def save(self,
              path_model_file: str):
