@@ -62,7 +62,7 @@ class GNNLayer(Layer):
             raise AssertionError('Unknown node aggregation scheme \'{}\' was given.'.format(self.__node_aggr_scheme))
 
         if layer_norm:
-            self._modules.append(LayerNorm(dim_out))
+            self._modules.append((LayerNorm(dim_out), 'x -> x'))
 
         if act_func is not None:
             self._modules.append(get_act_func(act_func))
@@ -176,7 +176,12 @@ class GNN(PyTorchModel):
 
         # Readout.
         if self._readout_method is not None:
-            h = self._readout(h, x.batch)
+            if isinstance(x, Batch):
+                batch = x.batch
+            else:
+                batch = torch.zeros(h.shape[0], dtype=torch.long).cuda()
+
+            h = self._readout(h, batch)
 
         # Prediction layer(s).
         out = self._pred_layers(h)
@@ -210,15 +215,15 @@ class GNN(PyTorchModel):
         self.eval()
 
         if isinstance(x, torch_geometric.data.Data):
-            batch = Batch.from_data_list([x])
+            _x = x
         else:
-            batch = Batch.from_data_list(x.x)
+            _x = Batch.from_data_list(x.x)
 
         with torch.no_grad():
             if is_gpu_runnable():
-                return self(batch.cuda()).cpu()
+                return self(_x.cuda()).cpu()
             else:
-                return self(batch)
+                return self(_x)
 
 
 class GCN(GNN):
@@ -235,11 +240,11 @@ class GCN(GNN):
 
             aggr_layers = [
                 GNNLayer(node_aggr_scheme=ALG_GCN, dim_in_node=dim_in_node, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_GCN, dim_in_node=256, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_GCN, dim_in_node=256, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU)
+                         layer_norm=False, act_func=ACT_FUNC_PRELU)
             ]
             pred_layers = [
                 FCLayer(dim_in=256, dim_out=256, batch_norm=True, act_func=ACT_FUNC_PRELU),
@@ -264,11 +269,11 @@ class GAT(GNN):
 
             aggr_layers = [
                 GNNLayer(node_aggr_scheme=ALG_GAT, dim_in_node=dim_in_node, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_GAT, dim_in_node=256, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_GAT, dim_in_node=256, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU)
+                         layer_norm=False, act_func=ACT_FUNC_PRELU)
             ]
             pred_layers = [
                 FCLayer(dim_in=256, dim_out=256, batch_norm=True, act_func=ACT_FUNC_PRELU),
@@ -293,11 +298,11 @@ class GIN(GNN):
 
             aggr_layers = [
                 GNNLayer(node_aggr_scheme=ALG_GIN, dim_in_node=dim_in_node, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_GIN, dim_in_node=256, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_GIN, dim_in_node=256, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU)
+                         layer_norm=False, act_func=ACT_FUNC_PRELU)
             ]
             pred_layers = [
                 FCLayer(dim_in=256, dim_out=256, batch_norm=True, act_func=ACT_FUNC_PRELU),
@@ -323,11 +328,11 @@ class ECCNN(GNN):
 
             aggr_layers = [
                 GNNLayer(node_aggr_scheme=ALG_ECCNN, dim_in_node=dim_in_node, dim_in_edge=dim_in_edge, dim_out=128,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_ECCNN, dim_in_node=128, dim_in_edge=dim_in_edge, dim_out=64,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_ECCNN, dim_in_node=64, dim_in_edge=dim_in_edge, dim_out=64,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU)
+                         layer_norm=False, act_func=ACT_FUNC_PRELU)
             ]
             pred_layers = [
                 FCLayer(dim_in=64, dim_out=128, batch_norm=True, act_func=ACT_FUNC_PRELU),
@@ -357,11 +362,11 @@ class CGCNN(GNN):
             ]
             aggr_layers = [
                 GNNLayer(node_aggr_scheme=ALG_CGCNN, dim_in_node=256, dim_in_edge=dim_in_edge, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_CGCNN, dim_in_node=256, dim_in_edge=dim_in_edge, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_CGCNN, dim_in_node=256, dim_in_edge=dim_in_edge, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU)
+                         layer_norm=False, act_func=ACT_FUNC_PRELU)
             ]
             pred_layers = [
                 FCLayer(dim_in=256, dim_out=256, batch_norm=True, act_func=ACT_FUNC_PRELU),
@@ -387,11 +392,11 @@ class TFGNN(GNN):
 
             aggr_layers = [
                 GNNLayer(node_aggr_scheme=ALG_TFGNN, dim_in_node=dim_in_node, dim_in_edge=dim_in_edge, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_TFGNN, dim_in_node=256, dim_in_edge=dim_in_edge, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU),
+                         layer_norm=False, act_func=ACT_FUNC_PRELU),
                 GNNLayer(node_aggr_scheme=ALG_TFGNN, dim_in_node=256, dim_in_edge=dim_in_edge, dim_out=256,
-                         layer_norm=True, act_func=ACT_FUNC_PRELU)
+                         layer_norm=False, act_func=ACT_FUNC_PRELU)
             ]
             pred_layers = [
                 FCLayer(dim_in=256, dim_out=256, batch_norm=True, act_func=ACT_FUNC_PRELU),
