@@ -41,7 +41,7 @@ class HparamOptProblem(Problem):
 
     def run_model(self, hparams):
         if isinstance(self.model, SKLearnModel):
-            _model = SKLearnModel(alg=self.model.alg_id, **hparams)
+            _model = SKLearnModel(alg_id=self.model.alg_id, **hparams)
             _model.fit(self.dataset_train)
             preds = _model.predict(self.dataset_val)
         else:
