@@ -1,7 +1,10 @@
 import torch
+import torch_geometric.data
+from typing import Union
+from torch.nn import ModuleList
 from torch.nn.functional import relu
 from torch.utils.data import DataLoader
-from torch.nn import ModuleList
+from torch_geometric.data import Batch
 from ailca.core.env import *
 from ailca.core.sys import is_gpu_runnable
 from ailca.data.multimodal import MultimodalDataset
@@ -38,11 +41,7 @@ class MultimodalNet(PyTorchModel):
 
     def forward(self,
                 x: list) -> torch.Tensor:
-        h = list()
-        for i in range(0, len(self.__nets)):
-            h.append(self.__net_modules[i](x[i]))
-
-        h = torch.hstack(h)
+        h = torch.hstack([self.__net_modules[i](x[i]) for i in range(0, len(self.__nets))])
         h = relu(self.fc1(h))
         out = self.fc2(h)
 
@@ -83,21 +82,43 @@ class MultimodalNet(PyTorchModel):
         return train_loss / len(data_loader)
 
     def predict(self,
-                dataset: MultimodalDataset) -> torch.Tensor:
+                x: Union[list, MultimodalDataset]) -> torch.Tensor:
         # Set the model to the evaluation model.
         self.eval()
 
-        preds = list()
-        data_loader = get_data_loader(dataset, batch_size=64, shuffle=False)
+        if isinstance(x, list):
+            # Predict target value for single input data.
+            _x = list()
 
-        with torch.no_grad():
-            for x, _ in data_loader:
+            for d in x:
+                if isinstance(d, torch.Tensor):
+                    _x.append(torch.stack([d, d]))
+                elif isinstance(d, torch_geometric.data.Data):
+                    _x.append(Batch.from_data_list([d, d]))
+                else:
+                    raise TypeError('Input data of unsupported data type: {}'.format(d.__class__))
+
+            with torch.no_grad():
                 if is_gpu_runnable():
                     for i in range(0, len(x)):
-                        x[i] = x[i].cuda()
+                        _x[i] = _x[i].cuda()
 
-                    preds.append(self(x).cpu())
+                    return self(_x).cpu()[0]
                 else:
-                    preds.append(self(x))
+                    return self(_x)[0]
+        else:
+            # Predict target values for a set of input data.
+            preds = list()
+            data_loader = get_data_loader(x, batch_size=64, shuffle=False)
 
-        return torch.vstack(preds)
+            with torch.no_grad():
+                for _x, _ in data_loader:
+                    if is_gpu_runnable():
+                        for i in range(0, len(_x)):
+                            _x[i] = _x[i].cuda()
+
+                        preds.append(self(_x).cpu())
+                    else:
+                        preds.append(self(_x))
+
+            return torch.vstack(preds)
